@@ -162,8 +162,8 @@ class IotRedisPublisher(IotRedisBasic):
             if not isinstance(data, dict):
                 raise TypeError("Type has to be a dictionary")
             return self.rdb.publish(channel, json.dumps(data))
-        except ConnectionError as _:
-            print("error trying to publish")
+        except ConnectionError as err:
+            raise ConnectionError(f"error trying to publish: {err}")
 
 
 class IotRedisPubSub(IotRedisPublisher, IotRedisSubscriber):
